Visualization of Results — sxdm v0.5 documentation

# Visualization of Results

## Region of Interest Viewer

Main Viewer This will bring up the default Region Of Interest viewer, once the `test_fs.roi_results` have been calculated.

    test_fs.roi_viewer()

## Centroid Analysis Viewer

Main Viewer This will bring up the default Region Of Interest viewer, once the `test_fs.centroid_results` have been calculated.

    test_fs.centroid_viewer()

## Return Raw Centroid Map Values

Takes the test_fs.results and a User defined map_type and returns either the centroid data or the ROI data for the `test_fs.resutls` variable.

`results` (nd.array) - the test_fs.results value

`map_type` - acceptable values - full_roi, chi_centroid, ttheta_centroid

## Make New Bound For Centroid Maps

The centroid maps are in values associated with their centroid position of the .tif image dimensions (usually 516, 516). To change what the bound/values are for the centroid values the user can set values for user_map and new_bounds to rebound the centroid maps.

`user_map` - the output of the centroid_roi_map() function

`new_bounds` - np.linspace(lowerbound, higherbound, dim of image)